@@ -2,9 +2,10 @@ package CatalystX::CRUD::Controller::RHTMLO;
 use strict;
 use base qw( CatalystX::CRUD::Controller );
 use Carp;
-use Class::C3;
+use MRO::Compat;
+use mro 'c3';
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =head1 NAME
 
